@@ -1,6 +1,7 @@
 import requests
 import uuid
 from ._utils.consts import *
+from ._utils._exceptions import WrongCreds
 import abc
 
 
@@ -66,7 +67,7 @@ class PasswordAuth(_RedditAuthBase):
         else:
             self._reddit_session = self._do_login()
             if self._reddit_session is None:
-                raise Exception("Wrong username or password")
+                raise WrongCreds("Wrong username or password")
             self.api_token = self._get_api_token()
 
         return super(PasswordAuth, self).authenticate()
@@ -79,9 +80,8 @@ class PasswordAuth(_RedditAuthBase):
             'client-vendor-id': self._client_vendor_uuid,
         }
         data = '{"scopes":["*"]}'
-        response = requests.post(f'{ACCOUNTS_REDDIT}/api/access_token', headers=headers, cookies=cookies, data=data).json()
-        api_token = response['access_token']
-        return api_token
+        response = requests.post(f'{ACCOUNTS_REDDIT}/api/access_token', headers=headers, cookies=cookies, data=data)
+        return response.json()['access_token']
 
     def _do_login(self):
         headers = {
